rxnGeneMapping: This function is used to establish the mappping between rxn...

Description Usage Arguments

View source: R/model change.R

Description

This function is used to establish the mappping between rxn and gene Title

Usage

1
rxnGeneMapping(rxnid_gpr)

Arguments

rxnid_gpr

a dataframe contains two columns, GPR and Abbreviation


SysBioChalmers/FALCONET documentation built on Dec. 5, 2020, 11:35 a.m.